@@ -17,28 +17,24 @@
 ##'   up the plot
 ##' @return a vector (factor) containing 1's and 2's, denoting the plants
 ##'   finally survived
-##' @note \code{2 * nmax} image frames will actually be produced, and the
-##'   option \code{nmax} will be adjusted to \code{2 * nmax} in the end.
+##' @note \code{2 * ani.options('nmax')} image frames will actually be produced.
 ##' @author Yihui Xie <\url{http://yihui.name}>
 ##' @references This animation is motivated by a question raised from Jing
 ##'   Jiao, a student in biology, to show the evolution of two species.
 ##'
 ##' The original post is in the forum of the ``Capital of Statistics'':
-##'   \url{http://cos.name/bbs/read.php?tid=14093} (in Chinese)
+##'   \url{http://cos.name/cn/topic/14093} (in Chinese)
 ##' @keywords dynamic distribution
 ##' @examples
 ##'
-##' oopt = ani.options(nmax = 50, interval = 0.3)
+##' oopt = ani.options(nmax = ifelse(interactive(), 50, 2), interval = 0.3)
 ##' par(ann = FALSE, mar = rep(0, 4))
 ##' ecol.death.sim()
 ##'
-##' \dontrun{
 ##' ## large scale simulation
-##' ani.options(nmax = 1000, interval = 0.02)
+##' ani.options(nmax = ifelse(interactive(), 1000, 2), interval = 0.02)
 ##' ecol.death.sim(col.sp = c(8, 2), pch.sp = c(20, 17))
 ##'
-##' }
-##'
 ##' ani.options(oopt)
 ##'
 ecol.death.sim = function(nr = 10, nc = 10, num.sp = c(50, 50), col.sp = c(1,
@@ -47,22 +43,20 @@ ecol.death.sim = function(nr = 10, nc = 10, num.sp = c(50, 50), col.sp = c(1,
     y = rep(1:nr, each = nc)
     p = factor(sample(rep(1:2, num.sp)), levels = 1:2)
     nmax = ani.options("nmax")
-    interval = ani.options("interval")
     for (i in 1:nmax) {
         plot(1:nc, 1:nr, type = "n", xlim = c(0.5, nc + 0.5),
             ylim = c(0.5, nr + 0.5), ...)
         abline(h = 1:nr, v = 1:nc, col = "lightgray", lty = 3)
         points(x, y, col = col.sp[p], pch = pch.sp[p], cex = cex)
-        Sys.sleep(interval)
+        ani.pause()
         idx = sample(nr * nc, 1)
         points(x[idx], y[idx], pch = pch.die, col = col.die,
             cex = cex, lwd = 3)
         tbl = as.vector(table(p))
         tbl = tbl + if (as.integer(p[idx]) > 1) c(0, -1) else c(-1, 0)
         p[idx] = sample(1:2, 1, prob = tbl)
-        Sys.sleep(interval)
+        ani.pause()
     }
-    ani.options(nmax = 2 * nmax)
     invisible(p)
 }
 
